@@ -9,11 +9,11 @@ use File::Find::Rule;
 use File::Basename;
 
 use EPublisher::Source::Base;
-use EPublisher::Utils::PPI qw(extract_pod);
+use EPublisher::Utils::PPI qw(extract_pod extract_package);
 
 our @ISA = qw( EPublisher::Source::Base );
 
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 sub load_source{
     my ($self) = @_;
@@ -52,6 +52,10 @@ sub load_source{
             ($title) = $pod =~ m{ =head1 \s+ (.*) }x;
             $title = '' if !defined $title;
         }
+        elsif ( $options->{title} and $options->{title} eq 'package' ) {
+            my $package = extract_package( $file, $self->_config );
+            $title = $package if $package;
+        }
         elsif ( $options->{title} and $options->{title} ne 'pod' ) {
             $title = $options->{title};
         }
@@ -74,7 +78,7 @@ EPublisher::Source::Plugin::Dir - Dir source plugin
 
 =head1 VERSION
 
-version 0.8
+version 0.9
 
 =head1 SYNOPSIS
 
